@@ -1,14 +1,14 @@
 """Base functionality for parsers."""
 
 from abc import ABC, abstractmethod
-from typing import Mapping
+from typing import Any
 
 
 class Parser(ABC):
     """Base parser class."""
 
     @abstractmethod
-    def __call__(self, config: Mapping):
+    def __call__(self, config: Any):
         raise NotImplementedError()
 
 
@@ -18,9 +18,9 @@ class ChainParser(Parser):
     def __init__(self, *parsers: Parser):
         self.parsers = parsers
 
-    def __call__(self, config: Mapping):
+    def __call__(self, config: Any):
         parsed = config
-        for parser in self.parsers:
+        for parser in self:
             parsed = parser(parsed)
         return parsed
 
