@@ -1,8 +1,10 @@
+# pylint: disable=protected-access
 """Test launcher.base."""
 
 import pytest
+import pkg_resources
+from typing import Any
 
-from fromconfig.launcher.base import _get_cls
 import fromconfig
 
 from fromconfig.launcher import HParamsLauncher
@@ -33,13 +35,42 @@ def test_launcher_is_abstract():
         pytest.param("does not exists", KeyError, id="missing-key"),
     ],
 )
-def test_get_cls(name, expected):
+def test_launcher_classes(name, expected):
     """Test _get_cls."""
     if issubclass(expected, fromconfig.launcher.Launcher):
-        assert _get_cls(name) is expected
+        assert fromconfig.launcher.base._classes()[name] is expected
     else:
         with pytest.raises(expected):
-            _get_cls(name)
+            fromconfig.launcher.base._classes()[name]  # pylint: disable=expression-not-assigned
+
+
+def test_launcher_classes_extension(monkeypatch):
+    """Test launcher classes extension."""
+
+    fromconfig.launcher.base._CLASSES.clear()  # Clear internal and external launchers
+
+    class DummyModule:
+        class DummyLauncher(fromconfig.launcher.Launcher):
+            def __call__(self, config: Any, command: str = ""):
+                ...
+
+    class EntryPoint:
+        def __init__(self, name, module):
+            self.name = name
+            self.module = module
+
+        def load(self):
+            return self.module
+
+    # Test discovery
+    monkeypatch.setattr(pkg_resources, "iter_entry_points", lambda *_: [EntryPoint("dummy", DummyModule)])
+    fromconfig.launcher.base._load()
+    fromconfig.utils.testing.assert_launcher_is_discovered("dummy", DummyModule.DummyLauncher)
+    assert fromconfig.launcher.base._classes()["dummy"] == DummyModule.DummyLauncher
+
+    # Test that loading again causes errors because of duplicates
+    with pytest.raises(ValueError):
+        fromconfig.launcher.base._load()
 
 
 @pytest.mark.parametrize(
@@ -47,13 +78,14 @@ def test_get_cls(name, expected):
     [
         pytest.param("local", LocalLauncher(), id="local"),
         pytest.param("dry", DryLauncher(), id="dry"),
+        pytest.param(DryLauncher(), DryLauncher(), id="dry-instance"),
         pytest.param(
             ["hparams", "parser", "logging", "local"],
             HParamsLauncher(ParserLauncher(LoggingLauncher(LocalLauncher()))),
-            id="hparams+parser",
+            id="hparams+parser+logging+local",
         ),
-        pytest.param({"sweep": [], "log": [], "parse": []}, LocalLauncher(), id="only-run"),
         pytest.param({"_attr_": "fromconfig.launcher.LocalLauncher"}, LocalLauncher(), id="fromconfig"),
+        pytest.param({"_attr_": "local"}, LocalLauncher(), id="fromconfig-short"),
         pytest.param(
             {"_attr_": "fromconfig.launcher.HParamsLauncher", "launcher": "local"},
             HParamsLauncher(LocalLauncher()),
@@ -64,6 +96,9 @@ def test_get_cls(name, expected):
             ValueError,
             id="fromconfig+nested-duplicate",
         ),
+        pytest.param(
+            [HParamsLauncher(None), "local"], ValueError, id="fromconfig+nested+already-instantiated-cannot-wrap",
+        ),
         pytest.param(1, TypeError, id="incorrect-type"),
     ],
 )
